@@ -61,7 +61,6 @@ class ProxySQL_Checksum_Value_2: public ProxySQL_Checksum_Value {
 	time_t last_changed;
 	unsigned int diff_check;
 	ProxySQL_Checksum_Value_2() {
-		ProxySQL_Checksum_Value();
 		last_changed = 0;
 		last_updated = 0;
 		diff_check = 0;
@@ -96,7 +95,7 @@ public:
 	uint16_t port;
 	ProxySQL_Node_Address(char *h, uint16_t p) : ProxySQL_Node_Address(h, p, NULL) {
 		// resolving DNS if available in Cache
-		if (h) {
+		if (h && p) {
 			size_t ip_count = 0;
 			const std::string& ip = MySQL_Monitor::dns_lookup(h, false, &ip_count);
 
@@ -274,6 +273,7 @@ class ProxySQL_Cluster_Nodes {
 	bool Update_Node_Metrics(char * _h, uint16_t _p, MYSQL_RES *_r, unsigned long long _response_time);
 	bool Update_Global_Checksum(char * _h, uint16_t _p, MYSQL_RES *_r);
 	bool Update_Node_Checksums(char * _h, uint16_t _p, MYSQL_RES *_r);
+	void Reset_Global_Checksums(bool lock);
 	void update_prometheus_nodes_metrics();
 	SQLite3_result * dump_table_proxysql_servers();
 	SQLite3_result * stats_proxysql_servers_checksums();
@@ -453,6 +453,9 @@ class ProxySQL_Cluster {
 	bool Update_Node_Checksums(char * _h, uint16_t _p, MYSQL_RES *_r = NULL) {
 		return nodes.Update_Node_Checksums(_h, _p, _r);
 	}
+	void Reset_Global_Checksums(bool lock) {
+		nodes.Reset_Global_Checksums(lock);
+	}
 	SQLite3_result *dump_table_proxysql_servers() {
 		return nodes.dump_table_proxysql_servers();
 	}
