@@ -173,11 +173,10 @@ enum mysql_variable_name {
 	SQL_CHARACTER_SET_CONNECTION,
 	SQL_CHARACTER_SET_CLIENT,
 	SQL_CHARACTER_SET_DATABASE,
+	SQL_COLLATION_CONNECTION,
+	SQL_NAME_LAST_LOW_WM,
 	SQL_ISOLATION_LEVEL,
 	SQL_TRANSACTION_READ,
-	SQL_COLLATION_CONNECTION,
-	SQL_WSREP_SYNC_WAIT,
-	SQL_NAME_LAST_LOW_WM,
 	SQL_AURORA_READ_REPLICA_READ_COMMITTED,
 	SQL_AUTO_INCREMENT_INCREMENT,
 	SQL_AUTO_INCREMENT_OFFSET,
@@ -195,11 +194,13 @@ enum mysql_variable_name {
 	SQL_LC_MESSAGES,
 	SQL_LC_TIME_NAMES,
 	SQL_LOCK_WAIT_TIMEOUT,
+	SQL_LOG_SLOW_FILTER,
 	SQL_LONG_QUERY_TIME,
 	SQL_MAX_EXECUTION_TIME,
 	SQL_MAX_HEAP_TABLE_SIZE,
 	SQL_MAX_JOIN_SIZE,
 	SQL_MAX_SORT_LENGTH,
+	SQL_MAX_STATEMENT_TIME,
 	SQL_OPTIMIZER_PRUNE_LEVEL,
 	SQL_OPTIMIZER_SEARCH_DEPTH,
 	SQL_OPTIMIZER_SWITCH,
@@ -209,15 +210,21 @@ enum mysql_variable_name {
 	SQL_SORT_BUFFER_SIZE,
 	SQL_SQL_AUTO_IS_NULL,
 	SQL_SQL_BIG_SELECTS,
+	SQL_GENERATE_INVISIBLE_PRIMARY_KEY,
 	SQL_SQL_LOG_BIN,
 	SQL_SQL_MODE,
+	SQL_QUOTE_SHOW_CREATE,
+	SQL_REQUIRE_PRIMARY_KEY,
 	SQL_SQL_SAFE_UPDATES,
 	SQL_SQL_SELECT_LIMIT,
 	SQL_TIME_ZONE,
 	SQL_TIMESTAMP,
 	SQL_TMP_TABLE_SIZE,
+	SQL_NEXT_ISOLATION_LEVEL,
+	SQL_NEXT_TRANSACTION_READ,
 	SQL_UNIQUE_CHECKS,
 	SQL_WSREP_OSU_METHOD,
+	SQL_WSREP_SYNC_WAIT,
 	SQL_NAME_LAST_HIGH_WM,
 };
 
@@ -249,6 +256,8 @@ enum session_status {
 	SETTING_MULTIPLE_VARIABLES,
 	SETTING_SET_NAMES,
 	SHOW_WARNINGS,
+	SETTING_NEXT_ISOLATION_LEVEL,
+	SETTING_NEXT_TRANSACTION_READ,
 	session_status___NONE // special marker
 };
 
@@ -546,7 +555,7 @@ struct __SQP_query_parser_t {
 struct _PtrSize_t {
   unsigned int size;
   void *ptr;
-}; 
+};
 // struct for debugging module
 #ifdef DEBUG
 struct _debug_level {
@@ -597,7 +606,7 @@ struct mysql_protocol_events {
 
 // this struct define global variable entries, and how these are configured during startup
 struct _global_variable_entry_t {
-	const char *group_name;	// [group name] in proxysql.cnf 
+	const char *group_name;	// [group name] in proxysql.cnf
 	const char *key_name;	// key name
 	int dynamic;	// if dynamic > 0 , reconfigurable
 	//GOptionArg arg;	// type of variable
@@ -759,7 +768,7 @@ EXTERN global_variables glovars;
 #ifndef GLOBAL_DEFINED_OPTS_ENTRIES
 #define GLOBAL_DEFINED_OPTS_ENTRIES
 ProxySQL_GlobalVariables GloVars {};
-#endif // GLOBAL_DEFINED_OPTS_ENTRIES 
+#endif // GLOBAL_DEFINED_OPTS_ENTRIES
 #ifndef GLOBAL_DEFINED_HOSTGROUP
 #define GLOBAL_DEFINED_HOSTGROUP
 MySQL_HostGroups_Manager *MyHGM;
@@ -810,6 +819,7 @@ __thread int mysql_thread___connect_timeout_server_max;
 __thread int mysql_thread___query_processor_iterations;
 __thread int mysql_thread___query_processor_regex;
 __thread int mysql_thread___set_query_lock_on_hostgroup;
+__thread int mysql_thread___set_parser_algorithm;
 __thread int mysql_thread___reset_connection_algorithm;
 __thread uint32_t mysql_thread___server_capabilities;
 __thread int mysql_thread___auto_increment_delay_multiplex;
@@ -976,6 +986,7 @@ extern __thread int mysql_thread___connect_timeout_server_max;
 extern __thread int mysql_thread___query_processor_iterations;
 extern __thread int mysql_thread___query_processor_regex;
 extern __thread int mysql_thread___set_query_lock_on_hostgroup;
+extern __thread int mysql_thread___set_parser_algorithm;
 extern __thread int mysql_thread___reset_connection_algorithm;
 extern __thread uint32_t mysql_thread___server_capabilities;
 extern __thread int mysql_thread___auto_increment_delay_multiplex;
@@ -1128,13 +1139,12 @@ mysql_variable_st mysql_tracked_variables[] {
 	{ SQL_CHARACTER_SET_CONNECTION, SETTING_VARIABLE, false, false, false, false, (char *)"character_set_connection", (char *)"character_set_connection", (char *)"utf8", false } ,
 	{ SQL_CHARACTER_SET_CLIENT,     SETTING_VARIABLE, false, false, false, false, (char *)"character_set_client", (char *)"character_set_client", (char *)"utf8" , false} ,
 	{ SQL_CHARACTER_SET_DATABASE,   SETTING_VARIABLE, false, false, false, false, (char *)"character_set_database", (char *)"character_set_database", (char *)"utf8" , false} ,
+	{ SQL_COLLATION_CONNECTION, SETTING_VARIABLE,     true,  false, false, false, (char *)"collation_connection", (char *)"collation_connection", (char *)"utf8_general_ci" , true} ,
+//    { SQL_NET_WRITE_TIMEOUT,    SETTING_VARIABLE,     false, false, true,  false, (char *)"net_write_timeout", (char *)"net_write_timeout", (char *)"60" , false} ,
+	{ SQL_NAME_LAST_LOW_WM,     SETTING_VARIABLE,     false, false, true,  false, (char *)"placeholder", (char *)"placeholder", (char *)"0" , false} , // this is just a placeholder to separate the previous index from the next block
 	{ SQL_ISOLATION_LEVEL,  SETTING_ISOLATION_LEVEL,  false, true,  false, false, (char *)"SESSION TRANSACTION ISOLATION LEVEL", (char *)"isolation_level", (char *)"READ COMMITTED" , false} ,
 	// NOTE: we also need support for  transaction_read_only session variable
 	{ SQL_TRANSACTION_READ, SETTING_TRANSACTION_READ, false, true,  false, false, (char *)"SESSION TRANSACTION READ", (char *)"transaction_read", (char *)"WRITE" , false} ,
-	{ SQL_COLLATION_CONNECTION, SETTING_VARIABLE,     true,  false, false, false, (char *)"collation_connection", (char *)"collation_connection", (char *)"utf8_general_ci" , true} ,
-//    { SQL_NET_WRITE_TIMEOUT,    SETTING_VARIABLE,     false, false, true,  false, (char *)"net_write_timeout", (char *)"net_write_timeout", (char *)"60" , false} ,
-	{ SQL_WSREP_SYNC_WAIT,      SETTING_VARIABLE,     false, false, true,  false, (char *)"wsrep_sync_wait", (char *)"wsrep_sync_wait", (char *)"0" , false} ,
-	{ SQL_NAME_LAST_LOW_WM,     SETTING_VARIABLE,     false, false, true,  false, (char *)"placeholder", (char *)"placeholder", (char *)"0" , false} , // this is just a placeholder to separate the previous index from the next block
 	{ SQL_AURORA_READ_REPLICA_READ_COMMITTED, SETTING_VARIABLE, false, false, false, true, ( char *)"aurora_read_replica_read_committed", NULL, (char *)"" , false} ,
 	{ SQL_AUTO_INCREMENT_INCREMENT,   SETTING_VARIABLE, false, false, true,  false, (char *)"auto_increment_increment",   NULL, (char *)"" , false} ,
 	{ SQL_AUTO_INCREMENT_OFFSET,      SETTING_VARIABLE, false, false, true,  false, (char *)"auto_increment_offset",      NULL, (char *)"" , false} ,
@@ -1152,11 +1162,16 @@ mysql_variable_st mysql_tracked_variables[] {
 	{ SQL_LC_MESSAGES,                SETTING_VARIABLE, true,  false, false, false, (char *)"lc_messages",                NULL, (char *)"" , false} ,
 	{ SQL_LC_TIME_NAMES,              SETTING_VARIABLE, true,  false, false, false, (char *)"lc_time_names",              NULL, (char *)"" , false} ,
 	{ SQL_LOCK_WAIT_TIMEOUT,          SETTING_VARIABLE, false, false, true,  false, (char *)"lock_wait_timeout",          NULL, (char *)"" , false} ,
+// log_queries_not_using_indexes is not enabled because in MySQL it is *only* a global variable, while in MariaDB is a global *and* session variable .
+// We believe it is not the time to create a lot of exceptions and complex logic for conflicting backend implementations
+//	{ SQL_LOG_QUERIES_NOT_USING_INDEXES, SETTING_VARIABLE, false,  false, false, true, (char *)"log_queries_not_using_indexes", NULL, (char *)"OFF" , false} ,
+	{ SQL_LOG_SLOW_FILTER,            SETTING_VARIABLE, true,  false, false, false, (char *)"log_slow_filter",            NULL, (char *)"" , false} ,
 	{ SQL_LONG_QUERY_TIME,            SETTING_VARIABLE, false, false, true,  false, (char *)"long_query_time",            NULL, (char *)"" , false} ,
 	{ SQL_MAX_EXECUTION_TIME,         SETTING_VARIABLE, false, false, true,  false, (char *)"max_execution_time",         NULL, (char *)"" , false} ,
 	{ SQL_MAX_HEAP_TABLE_SIZE,        SETTING_VARIABLE, false, false, true,  false, (char *)"max_heap_table_size",        NULL, (char *)"18446744073709547520" , false} ,
 	{ SQL_MAX_JOIN_SIZE,              SETTING_VARIABLE, false, false, true,  false, (char *)"max_join_size",              NULL, (char *)"18446744073709551615" , false} ,
 	{ SQL_MAX_SORT_LENGTH,            SETTING_VARIABLE, false, false, true,  false, (char *)"max_sort_length",            NULL, (char *)"" , false} ,
+	{ SQL_MAX_STATEMENT_TIME,         SETTING_VARIABLE, false, false, true,  false, (char *)"max_statement_time",         NULL, (char *)"" , false} ,
 	{ SQL_OPTIMIZER_PRUNE_LEVEL,      SETTING_VARIABLE, false, false, true,  false, (char *)"optimizer_prune_level",      NULL, (char *)"" , false} ,
 	{ SQL_OPTIMIZER_SEARCH_DEPTH,     SETTING_VARIABLE, false, false, true,  false, (char *)"optimizer_search_depth",     NULL, (char *)"" , false} ,
 	{ SQL_OPTIMIZER_SWITCH,           SETTING_VARIABLE, true,  false, false, false, (char *)"optimizer_switch",           NULL, (char *)"" , false} ,
@@ -1166,16 +1181,21 @@ mysql_variable_st mysql_tracked_variables[] {
 	{ SQL_SORT_BUFFER_SIZE,           SETTING_VARIABLE, false, false, true,  false, (char *)"sort_buffer_size",           NULL, (char *)"18446744073709551615" , false} ,
 	{ SQL_SQL_AUTO_IS_NULL,           SETTING_VARIABLE, true,  false, false, true,  (char *)"sql_auto_is_null",           NULL, (char *)"OFF" , false} ,
 	{ SQL_SQL_BIG_SELECTS,            SETTING_VARIABLE, true,  false, false, true,  (char *)"sql_big_selects",            NULL, (char *)"OFF" , true} ,
+	{ SQL_GENERATE_INVISIBLE_PRIMARY_KEY, SETTING_VARIABLE, false, false, false, true, (char *)"sql_generate_invisible_primary_key", NULL, (char *)"" , false} ,
 	{ SQL_SQL_LOG_BIN,                SETTING_VARIABLE, false, false, false, true,  (char *)"sql_log_bin",                NULL, (char *)"ON"  , false} ,
 	{ SQL_SQL_MODE,                   SETTING_VARIABLE, true,  false, false, false, (char *)"sql_mode" ,                  NULL, (char *)"" , false} ,
+	{ SQL_QUOTE_SHOW_CREATE,          SETTING_VARIABLE, false, false, false, true,  (char *)"sql_quote_show_create",      NULL, (char *)"" , false} ,
+	{ SQL_REQUIRE_PRIMARY_KEY,        SETTING_VARIABLE, false, false, false, true,  (char *)"sql_require_primary_key",    NULL, (char *)"" , false} ,
 	{ SQL_SQL_SAFE_UPDATES,           SETTING_VARIABLE, true,  false, false, true,  (char *)"sql_safe_updates",           NULL, (char *)"OFF" , false} ,
 	{ SQL_SQL_SELECT_LIMIT,           SETTING_VARIABLE, false, false, true,  false, (char *)"sql_select_limit",           NULL, (char *)"DEFAULT" , false} ,
 	{ SQL_TIME_ZONE,                  SETTING_VARIABLE, true,  false, false, false, (char *)"time_zone",                  NULL, (char *)"SYSTEM" , false} ,
 	{ SQL_TIMESTAMP,                  SETTING_VARIABLE, false, false, true,  false, (char *)"timestamp",                  NULL, (char *)"" , false} ,
 	{ SQL_TMP_TABLE_SIZE,             SETTING_VARIABLE, false, false, true,  false, (char *)"tmp_table_size",             NULL, (char *)"" , false} ,
+	{ SQL_NEXT_ISOLATION_LEVEL, SETTING_NEXT_ISOLATION_LEVEL, false, true,  false, false, (char *)"transaction isolation level", (char *)"next_isolation_level", (char *)"READ COMMITTED" , false} ,
+	{ SQL_NEXT_TRANSACTION_READ, SETTING_NEXT_TRANSACTION_READ, false, true,  false, false, (char *)"transaction read", (char *)"next_transaction_read", (char *)"WRITE" , false} ,
 	{ SQL_UNIQUE_CHECKS,              SETTING_VARIABLE, true,  false, false, true,  (char *)"unique_checks",              NULL, (char *)"" , false} ,
 	{ SQL_WSREP_OSU_METHOD,           SETTING_VARIABLE, true,  false, false, false, (char *)"wsrep_osu_method",           NULL, (char *)"" , false} ,
-
+	{ SQL_WSREP_SYNC_WAIT,			  SETTING_VARIABLE, false, false, true,  false, (char *)"wsrep_sync_wait",			  (char *)"wsrep_sync_wait", (char *)"0" , false} ,
 	/*
 	variables that will need input validation:
 	binlog_row_image
