@@ -26,6 +26,14 @@
 #include <pthread.h>
 #include "jemalloc.h"
 
+#ifndef NOJEM
+#if defined(__APPLE__) && defined(__MACH__)
+#ifndef mallctl
+#define mallctl(a, b, c, d, e) je_mallctl(a, b, c, d, e)
+#endif
+#endif // __APPLE__ and __MACH__
+#endif // NOJEM
+
 class Thread
 {
   public:
