@@ -3,6 +3,7 @@
 
 #include "sqlite3db.h"
 #include "prometheus_helpers.h"
+#include "gen_utils.h"
 
 #include <set>
 #include <cxxabi.h>
@@ -24,16 +25,21 @@ using std::unordered_map;
 #endif // CLOCK_MONOTONIC
 
 #ifdef DEBUG
-static unsigned long long pretime=0;
+__thread unsigned long long pretime=0;
 static pthread_mutex_t debug_mutex;
+static pthread_rwlock_t filters_rwlock;
+static SQLite3DB * debugdb_disk = NULL;
+sqlite3_stmt *statement1=NULL;
+static unsigned int debug_output = 1;
 #endif /* DEBUG */
 
+/*
 static inline unsigned long long debug_monotonic_time() {
 	struct timespec ts;
 	clock_gettime(CLOCK_MONOTONIC, &ts);
 	return (((unsigned long long) ts.tv_sec) * 1000000) + (ts.tv_nsec / 1000);
 }
-
+*/
 
 #define DEBUG_MSG_MAXSIZE	1024
 
@@ -48,7 +54,8 @@ static inline unsigned long long debug_monotonic_time() {
 std::set<std::string> debug_filters;
 
 static bool filter_debug_entry(const char *__file, int __line, const char *__func) {
-	pthread_mutex_lock(&debug_mutex);
+	//pthread_mutex_lock(&debug_mutex);
+	pthread_rwlock_rdlock(&filters_rwlock);
 	bool to_filter = false;
 	if (debug_filters.size()) { // if the set is empty we aren't performing any filter, so we won't search
 		std::string key(__file);
@@ -88,46 +95,63 @@ static bool filter_debug_entry(const char *__file, int __line, const char *__fun
 			}
 		}
 	}
-	pthread_mutex_unlock(&debug_mutex);
+	//pthread_mutex_unlock(&debug_mutex);
+	pthread_rwlock_unlock(&filters_rwlock);
 	return to_filter;
 }
 
 // we use this function to sent the filters to Admin
-// we hold here the mutex on debug_mutex
+// we hold here the lock on filters_rwlock
 void proxy_debug_get_filters(std::set<std::string>& f) {
-	pthread_mutex_lock(&debug_mutex);
+	//pthread_mutex_lock(&debug_mutex);
+	pthread_rwlock_rdlock(&filters_rwlock);
 	f = debug_filters;
-	pthread_mutex_unlock(&debug_mutex);
+	pthread_rwlock_unlock(&filters_rwlock);
+	//pthread_mutex_unlock(&debug_mutex);
 }
 
 // we use this function to get the filters from Admin
-// we hold here the mutex on debug_mutex
+// we hold here the lock on filters_rwlock
 void proxy_debug_load_filters(std::set<std::string>& f) {
-	pthread_mutex_lock(&debug_mutex);
+	//pthread_mutex_lock(&debug_mutex);
+	pthread_rwlock_wrlock(&filters_rwlock);
 	debug_filters.erase(debug_filters.begin(), debug_filters.end());
 	debug_filters = f;
-	pthread_mutex_unlock(&debug_mutex);
+	pthread_rwlock_unlock(&filters_rwlock);
+	//pthread_mutex_unlock(&debug_mutex);
 }
 
 void proxy_debug_func(enum debug_module module, int verbosity, int thr, const char *__file, int __line, const char *__func, const char *fmt, ...) {
 	assert(module<PROXY_DEBUG_UNKNOWN);
+	if (pretime == 0) { // never initialized
+		pretime=realtime_time();
+	}
 	if (GloVars.global.gdbg_lvl[module].verbosity < verbosity)
 		return;
 	if (filter_debug_entry(__file, __line, __func)) // check if the entry must be filtered
 		return;
+	char origdebugbuff[DEBUG_MSG_MAXSIZE];
 	char debugbuff[DEBUG_MSG_MAXSIZE];
 	char longdebugbuff[DEBUG_MSG_MAXSIZE*8];
+	char longdebugbuff2[DEBUG_MSG_MAXSIZE*8];
 	longdebugbuff[0]=0;
-	if (GloVars.global.foreground) {
+	longdebugbuff2[0]=0;
+	unsigned long long curtime=realtime_time();
+	bool write_to_disk = false;
+	if (debugdb_disk != NULL && (debug_output == 2 || debug_output == 3)) {
+		write_to_disk = true;
+	}
+	if (
+		GloVars.global.foreground
+		||
+		write_to_disk == true
+	) {
 		va_list ap;
 		va_start(ap, fmt);
-		vsnprintf(debugbuff, DEBUG_MSG_MAXSIZE,fmt,ap);
+		vsnprintf(origdebugbuff, DEBUG_MSG_MAXSIZE,fmt,ap);
 		va_end(ap);
-		pthread_mutex_lock(&debug_mutex);
-		unsigned long long curtime=debug_monotonic_time();
 		//fprintf(stderr, "%d:%s:%d:%s(): MOD#%d LVL#%d : %s" , thr, __file, __line, __func, module, verbosity, debugbuff);
-		sprintf(longdebugbuff, "%llu(%llu): %d:%s:%d:%s(): MOD#%d#%s LVL#%d : %s" , curtime, curtime-pretime, thr, __file, __line, __func, module, GloVars.global.gdbg_lvl[module].name, verbosity, debugbuff);
-		pretime=curtime;
+		sprintf(longdebugbuff, "%llu(%llu): %d:%s:%d:%s(): MOD#%d#%s LVL#%d : %s" , curtime, curtime-pretime, thr, __file, __line, __func, module, GloVars.global.gdbg_lvl[module].name, verbosity, origdebugbuff);
 	}
 #ifdef __GLIBC__
 	if (GloVars.global.gdbg_lvl[module].verbosity>=10) {
@@ -150,18 +174,65 @@ void proxy_debug_func(enum debug_module module, int verbosity, int thr, const ch
 			realname=abi::__cxa_demangle(debugbuff, 0, 0, &status);
 			if (realname) {
 				sprintf(debugbuff," ---- %s : %s\n", strings[i], realname);
-				strcat(longdebugbuff,debugbuff);
+				strcat(longdebugbuff2,debugbuff);
 			}
 		}
 		//printf("\n");
-		strcat(longdebugbuff,"\n");
+		//strcat(longdebugbuff2,"\n");
 		free(strings);
 //	} else {
 //		fprintf(stderr, "%s", longdebugbuff);
 	}
 #endif
-	if (strlen(longdebugbuff)) fprintf(stderr, "%s", longdebugbuff);
+	pthread_mutex_lock(&debug_mutex);
+	if (debugdb_disk == NULL) {
+		// default behavior
+		if (longdebugbuff[0] != 0) {
+			fprintf(stderr, "%s", longdebugbuff);
+		}
+		if (longdebugbuff2[0] != 0) {
+			if (GloVars.global.gdbg_lvl[module].verbosity>=10) {
+				fprintf(stderr, "%s\n", longdebugbuff2);
+			}
+		}
+	} else {
+		SQLite3DB *db = debugdb_disk;
+		int rc = 0;
+		if (statement1==NULL) {
+			const char *a = "INSERT INTO debug_log (id, time, lapse, thread, file, line, funct, modnum, modname, verbosity, message, note, backtrace) VALUES (NULL, ?1, ?2, ?3, ?4, ?5, ?6, ?7, ?8, ?9, ?10, NULL, ?11)";
+			rc=db->prepare_v2(a, &statement1);
+			ASSERT_SQLITE_OK(rc, db);
+		}
+		if (debug_output == 1 || debug_output == 3) {
+			// to stderr
+			if (longdebugbuff[0] != 0) {
+				fprintf(stderr, "%s", longdebugbuff);
+			}
+			if (longdebugbuff2[0] != 0) {
+				fprintf(stderr, "%s", longdebugbuff2);
+			}
+		}
+		if (write_to_disk == true) {
+			rc=(*proxy_sqlite3_bind_int64)(statement1, 1, curtime); ASSERT_SQLITE_OK(rc, db);
+			rc=(*proxy_sqlite3_bind_int64)(statement1, 2, curtime-pretime); ASSERT_SQLITE_OK(rc, db);
+			rc=(*proxy_sqlite3_bind_int64)(statement1, 3, thr); ASSERT_SQLITE_OK(rc, db);
+			rc=(*proxy_sqlite3_bind_text)(statement1,  4, __file, -1, SQLITE_TRANSIENT); ASSERT_SQLITE_OK(rc, db);
+			rc=(*proxy_sqlite3_bind_int64)(statement1, 5, __line); ASSERT_SQLITE_OK(rc, db);
+			rc=(*proxy_sqlite3_bind_text)(statement1,  6, __func, -1, SQLITE_TRANSIENT); ASSERT_SQLITE_OK(rc, db);
+			rc=(*proxy_sqlite3_bind_int64)(statement1, 7, module); ASSERT_SQLITE_OK(rc, db);
+			rc=(*proxy_sqlite3_bind_text)(statement1,  8, GloVars.global.gdbg_lvl[module].name, -1, SQLITE_TRANSIENT); ASSERT_SQLITE_OK(rc, db);
+			rc=(*proxy_sqlite3_bind_int64)(statement1, 9, verbosity); ASSERT_SQLITE_OK(rc, db);
+			rc=(*proxy_sqlite3_bind_text)(statement1, 10, origdebugbuff, -1, SQLITE_TRANSIENT); ASSERT_SQLITE_OK(rc, db);
+			rc=(*proxy_sqlite3_bind_text)(statement1, 11, longdebugbuff2, -1, SQLITE_TRANSIENT); ASSERT_SQLITE_OK(rc, db);
+			SAFE_SQLITE3_STEP2(statement1);
+			rc=(*proxy_sqlite3_clear_bindings)(statement1); ASSERT_SQLITE_OK(rc, db);
+			// Note: no assert() in proxy_debug_func() after sqlite3_reset() because it is possible that we are in shutdown
+			rc=(*proxy_sqlite3_reset)(statement1); // ASSERT_SQLITE_OK(rc, db);
+		}
+	}
 	pthread_mutex_unlock(&debug_mutex);
+	if (curtime != 0)
+		pretime=curtime;
 };
 #endif
 
@@ -376,7 +447,7 @@ void print_backtrace(void)
 void init_debug_struct() {	
 	int i;
 	pthread_mutex_init(&debug_mutex,NULL);
-	pretime=debug_monotonic_time();
+	pthread_rwlock_init(&filters_rwlock, NULL);
 	GloVars.global.gdbg_lvl= (debug_level *) malloc(PROXY_DEBUG_UNKNOWN*sizeof(debug_level));
 	for (i=0;i<PROXY_DEBUG_UNKNOWN;i++) {
 		GloVars.global.gdbg_lvl[i].module=(enum debug_module)i;
@@ -418,4 +489,13 @@ void init_debug_struct_from_cmdline() {
 		GloVars.global.gdbg_lvl[i].verbosity=GloVars.__cmd_proxysql_gdbg;
 	}
 }
+
+
+void proxysql_set_admin_debugdb_disk(SQLite3DB * _db) {
+	debugdb_disk = _db;
+}
+
+void proxysql_set_admin_debug_output(unsigned int _do) {
+	debug_output = _do;
+}
 #endif /* DEBUG */
