@@ -333,7 +333,7 @@ void SQLite3_Server_session_handler(MySQL_Session *sess, void *_pa, PtrSize_t *p
 	memcpy(query,(char *)pkt->ptr+sizeof(mysql_hdr)+1,query_length-1);
 	query[query_length-1]=0;
 
-#if defined(TEST_AURORA) || defined(TEST_GALERA) || defined(TEST_GROUPREP)
+#if defined(TEST_AURORA) || defined(TEST_GALERA) || defined(TEST_GROUPREP) || defined(TEST_READONLY) || defined(TEST_REPLICATIONLAG)
 	if (sess->client_myds->proxy_addr.addr == NULL) {
 		struct sockaddr addr;
 		socklen_t addr_len=sizeof(struct sockaddr);
@@ -363,7 +363,7 @@ void SQLite3_Server_session_handler(MySQL_Session *sess, void *_pa, PtrSize_t *p
 			sess->client_myds->proxy_addr.addr = strdup("unknown");
 		}
 	}
-#endif // TEST_AURORA || TEST_GALERA || TEST_GROUPREP
+#endif // TEST_AURORA || TEST_GALERA || TEST_GROUPREP || TEST_READONLY || TEST_REPLICATIONLAG
 
 	char *query_no_space=(char *)l_alloc(query_length);
 	memcpy(query_no_space,query,query_length);
@@ -534,13 +534,13 @@ void SQLite3_Server_session_handler(MySQL_Session *sess, void *_pa, PtrSize_t *p
 	if (query_no_space_length==SELECT_VERSION_COMMENT_LEN) {
 		if (!strncasecmp(SELECT_VERSION_COMMENT, query_no_space, query_no_space_length)) {
 			l_free(query_length,query);
-#if defined(TEST_AURORA) || defined(TEST_GALERA) || defined(TEST_GROUPREP)
+#if defined(TEST_AURORA) || defined(TEST_GALERA) || defined(TEST_GROUPREP) || defined(TEST_READONLY) || defined(TEST_REPLICATIONLAG)
 			char *a = (char *)"SELECT '(ProxySQL Automated Test Server) - %s'";
 			query = (char *)malloc(strlen(a)+strlen(sess->client_myds->proxy_addr.addr));
 			sprintf(query,a,sess->client_myds->proxy_addr.addr);
 #else
 			query=l_strdup("SELECT '(ProxySQL SQLite3 Server)'");
-#endif // TEST_AURORA || TEST_GALERA || TEST_GROUPREP
+#endif // TEST_AURORA || TEST_GALERA || TEST_GROUPREP || TEST_READONLY || TEST_REPLICATIONLAG
 			query_length=strlen(query)+1;
 			goto __run_query;
 		}
@@ -730,7 +730,7 @@ __end_show_commands:
 
 __run_query:
 	if (run_query) {
-#if defined(TEST_AURORA) || defined(TEST_GALERA) || defined(TEST_GROUPREP)
+#if defined(TEST_AURORA) || defined(TEST_GALERA) || defined(TEST_GROUPREP) || defined(TEST_READONLY) || defined(TEST_REPLICATIONLAG)
 		if (strncasecmp("SELECT",query_no_space,6)==0) {
 #ifdef TEST_AURORA
 			if (strstr(query_no_space,(char *)"REPLICA_HOST_STATUS")) {
@@ -784,6 +784,42 @@ __run_query:
 				}
 			}
 #endif // TEST_GROUPREP
+#ifdef TEST_READONLY
+			if (strncasecmp("SELECT @@global.read_only read_only ",query_no_space, strlen("SELECT @@global.read_only read_only "))==0) {
+				if (strlen(query_no_space) > strlen("SELECT @@global.read_only read_only ")+5) {
+					pthread_mutex_lock(&GloSQLite3Server->test_readonly_mutex);
+					// the current test doesn't try to simulate failures, therefore it will return immediately
+					if (GloSQLite3Server->readonly_map_size() == 0) {
+						// probably never initialized
+						GloSQLite3Server->load_readonly_table(sess);
+					}
+					int rc = GloSQLite3Server->readonly_test_value(query_no_space+strlen("SELECT @@global.read_only read_only "));
+					free(query);
+					char *a = (char *)"SELECT %d as read_only";
+					query = (char *)malloc(strlen(a)+2);
+					sprintf(query,a,rc);
+					pthread_mutex_unlock(&GloSQLite3Server->test_readonly_mutex);
+				}
+			}
+#endif // TEST_READONLY
+#ifdef TEST_REPLICATIONLAG
+			if (strncasecmp("SELECT SLAVE STATUS ", query_no_space, strlen("SELECT SLAVE STATUS ")) == 0) {
+				if (strlen(query_no_space) > strlen("SELECT SLAVE STATUS ") + 5) {
+					pthread_mutex_lock(&GloSQLite3Server->test_replicationlag_mutex);
+					// the current test doesn't try to simulate failures, therefore it will return immediately
+					if (GloSQLite3Server->replicationlag_map_size() == 0) {
+						// probably never initialized
+						GloSQLite3Server->load_replicationlag_table(sess);
+					}
+					const int rc = GloSQLite3Server->replicationlag_test_value(query_no_space + strlen("SELECT SLAVE STATUS "));
+					free(query);
+					char* a = (char*)"SELECT %d as Seconds_Behind_Master";
+					query = (char*)malloc(strlen(a) + 2);
+					sprintf(query, a, rc);
+					pthread_mutex_unlock(&GloSQLite3Server->test_replicationlag_mutex);
+				}
+			}
+#endif // TEST_REPLICATIONLAG
 			if (strstr(query_no_space,(char *)"Seconds_Behind_Master")) {
 				free(query);
 				char *a = (char *)"SELECT %d as Seconds_Behind_Master";
@@ -791,7 +827,7 @@ __run_query:
 				sprintf(query,a,rand()%30+10);
 			}
 		}
-#endif // TEST_AURORA || TEST_GALERA || TEST_GROUPREP
+#endif // TEST_AURORA || TEST_GALERA || TEST_GROUPREP || TEST_READONLY || TEST_REPLICATIONLAG
 		SQLite3_Session *sqlite_sess = (SQLite3_Session *)sess->thread->gen_args;
 		if (sess->autocommit==false) {
 			sqlite3 *db = sqlite_sess->sessdb->get_db();
@@ -850,6 +886,26 @@ __run_query:
 		}
 		sess->SQLite3_to_MySQL(resultset, error, affected_rows, &sess->client_myds->myprot, in_trans);
 		delete resultset;
+#ifdef TEST_READONLY
+		if (strncasecmp("SELECT",query_no_space,6)) {
+			if (strstr(query_no_space,(char *)"READONLY_STATUS")) {
+				// the table is writable
+				pthread_mutex_lock(&GloSQLite3Server->test_readonly_mutex);
+				GloSQLite3Server->load_readonly_table(sess);
+				pthread_mutex_unlock(&GloSQLite3Server->test_readonly_mutex);
+			}
+		}
+#endif // TEST_READONLY
+#ifdef TEST_REPLICATIONLAG
+		if (strncasecmp("SELECT", query_no_space, 6)) {
+			if (strstr(query_no_space, (char*)"REPLICATIONLAG_HOST_STATUS")) {
+				// the table is writable
+				pthread_mutex_lock(&GloSQLite3Server->test_replicationlag_mutex);
+				GloSQLite3Server->load_replicationlag_table(sess);
+				pthread_mutex_unlock(&GloSQLite3Server->test_replicationlag_mutex);
+			}
+		}
+#endif // TEST_REPLICATIONLAG
 	}
 	l_free(pkt->size-sizeof(mysql_hdr),query_no_space); // it is always freed here
 	l_free(query_length,query);
@@ -959,21 +1015,22 @@ static void *child_mysql(void *arg) {
 			}
 		}
 		sess->to_process=1;
-		// Get and set the client address before the sesion is processed.
-		union {
-			struct sockaddr_in in;
-			struct sockaddr_in6 in6;
-		} custom_sockaddr;
-		struct sockaddr *addr=(struct sockaddr *)malloc(sizeof(custom_sockaddr));
-		socklen_t addrlen=sizeof(custom_sockaddr);
-		memset(addr, 0, sizeof(custom_sockaddr));
-		sess->client_myds->client_addrlen=addrlen;
-		sess->client_myds->client_addr=addr;
-		int g_rc = getpeername(sess->client_myds->fd, addr, &addrlen);
-		if (g_rc == -1) {
-			proxy_error("'getpeername' failed with error: %d\n", g_rc);
+		if (sess->client_myds->client_addr == NULL) {
+			// Get and set the client address before the sesion is processed.
+			union {
+				struct sockaddr_in in;
+				struct sockaddr_in6 in6;
+			} custom_sockaddr;
+			struct sockaddr *addr=(struct sockaddr *)malloc(sizeof(custom_sockaddr));
+			socklen_t addrlen=sizeof(custom_sockaddr);
+			memset(addr, 0, sizeof(custom_sockaddr));
+			sess->client_myds->client_addrlen=addrlen;
+			sess->client_myds->client_addr=addr;
+			int g_rc = getpeername(sess->client_myds->fd, addr, &addrlen);
+			if (g_rc == -1) {
+				proxy_error("'getpeername' failed with error: %d\n", g_rc);
+			}
 		}
-
 		int rc=sess->handler();
 		if (rc==-1) goto __exit_child_mysql;
 	}
@@ -1026,12 +1083,16 @@ static void * sqlite3server_main_loop(void *arg)
 		for (i=1;i<nfds;i++) {
 			if (fds[i].revents==POLLIN) {
 				client_t = accept(fds[i].fd, (struct sockaddr*)&addr, &addr_size);
-				pthread_attr_getstacksize (&attr, &stacks);
-				pthread_mutex_lock (&sock_mutex);
-				client=(int *)malloc(sizeof(int));
-				*client= client_t;
-				if ( pthread_create(&child, &attr, child_func[callback_func[i]], client) != 0 )
-					perror("Thread creation");
+				if (client_t > 0) { // minor error handling
+					pthread_attr_getstacksize (&attr, &stacks);
+					pthread_mutex_lock (&sock_mutex);
+					client=(int *)malloc(sizeof(int));
+					*client= client_t;
+					if ( pthread_create(&child, &attr, child_func[callback_func[i]], client) != 0 )
+						perror("Thread creation");
+				} else {
+					proxy_error("accept() error:\n", strerror(errno));
+				}
 			}
 			fds[i].revents=0;
 		}
@@ -1041,7 +1102,9 @@ static void * sqlite3server_main_loop(void *arg)
 		// already taken will result into an 'assert' in ProxySQL side.
 		if (nfds == 1 && fds[0].revents == POLLNVAL) {
 			proxy_error("revents==POLLNVAL for FD=%d, events=%d\n", fds[i].fd, fds[i].events);
-			assert(fds[0].revents != POLLNVAL);
+			if (glovars.shutdown==0 && *shutdown==0) {
+				assert(fds[0].revents != POLLNVAL);
+			}
 		}
 __end_while_pool:
 		if (S_amll.get_version()!=version) {
@@ -1080,7 +1143,11 @@ __end_while_pool:
                                         c_split_2(sn, ":" , &add, &port);
                                 }
 
+#ifdef SO_REUSEPORT
+				int s = ( atoi(port) ? listen_on_port(add, atoi(port), 128, true) : listen_on_unix(add, 128));
+#else
 				int s = ( atoi(port) ? listen_on_port(add, atoi(port), 128) : listen_on_unix(add, 128));
+#endif // SO_REUSEPORT
 				if (s>0) { fds[nfds].fd=s; fds[nfds].events=POLLIN; fds[nfds].revents=0; callback_func[nfds]=0; socket_names[nfds]=strdup(sn); nfds++; }
 				if (add) free(add);
 				if (port) free(port);
@@ -1219,7 +1286,7 @@ SQLite3_Server::SQLite3_Server() {
 
 	variables.read_only=false;
 
-#if defined(TEST_AURORA) || defined(TEST_GALERA) || defined(TEST_GROUPREP)
+#if defined(TEST_AURORA) || defined(TEST_GALERA) || defined(TEST_GROUPREP) || defined(TEST_READONLY) || defined(TEST_REPLICATIONLAG) 
 	string s = "";
 
 #ifdef TEST_AURORA
@@ -1233,12 +1300,26 @@ SQLite3_Server::SQLite3_Server() {
 #ifdef TEST_GROUPREP
 	init_grouprep_ifaces_string(s);
 #endif // TEST_GROUPREP
+#ifdef TEST_READONLY
+	// for readonly test we listen on all IPs because we simulate a lot of clusters
+	if (!s.empty())
+		s += ";";
+	s += "0.0.0.0:3306";
+	pthread_mutex_init(&test_readonly_mutex, NULL);
+#endif //TEST_READONLY
+#ifdef TEST_REPLICATIONLAG
+	// for replication test we listen on all IPs
+	if (!s.empty())
+		s += ";";
+	s += "0.0.0.0:3306";
+	pthread_mutex_init(&test_replicationlag_mutex, NULL);
+#endif //TEST_REPLICATIONLAG
 
 	variables.mysql_ifaces=strdup(s.c_str());
 
 #else
 	variables.mysql_ifaces=strdup("127.0.0.1:6030");
-#endif // TEST_AURORA || TEST_GALERA || TEST_GROUPREP
+#endif // TEST_AURORA || TEST_GALERA || TEST_GROUPREP || TEST_READONLY || TEST_REPLICATIONLAG
 };
 
 
@@ -1449,7 +1530,7 @@ void SQLite3_Server::populate_grouprep_table(MySQL_Session *sess, int txs_behind
 #endif // TEST_GALERA
 
 
-#if defined(TEST_AURORA) || defined(TEST_GALERA) || defined(TEST_GROUPREP)
+#if defined(TEST_AURORA) || defined(TEST_GALERA) || defined(TEST_GROUPREP) || defined(TEST_READONLY) || defined(TEST_REPLICATIONLAG)
 void SQLite3_Server::insert_into_tables_defs(std::vector<table_def_t *> *tables_defs, const char *table_name, const char *table_def) {
 	table_def_t *td = new table_def_t;
 	td->table_name=strdup(table_name);
@@ -1479,7 +1560,7 @@ void SQLite3_Server::drop_tables_defs(std::vector<table_def_t *> *tables_defs) {
 		delete td;
 	}
 };
-#endif // TEST_AURORA || TEST_GALERA || defined(TEST_GROUPREP)
+#endif // TEST_AURORA || TEST_GALERA || TEST_GROUPREP || TEST_READONLY || TEST_REPLICATIONLAG
 
 void SQLite3_Server::wrlock() {
 	pthread_rwlock_wrlock(&rwlock);
@@ -1525,7 +1606,26 @@ bool SQLite3_Server::init() {
 	check_and_build_standard_tables(sessdb, tables_defs_grouprep);
 	GloAdmin->enable_grouprep_testing();
 #endif // TEST_GALERA
+#ifdef TEST_READONLY
+	tables_defs_readonly = new std::vector<table_def_t *>;
+	insert_into_tables_defs(tables_defs_readonly,
+		(const char *)"READONLY_STATUS",
+		(const char*)"CREATE TABLE READONLY_STATUS (hostname VARCHAR NOT NULL , port INT NOT NULL , read_only INT NOT NULL CHECK (read_only IN (0, 1)) DEFAULT 1 , PRIMARY KEY (hostname, port))");
+	check_and_build_standard_tables(sessdb, tables_defs_readonly);
+	GloAdmin->enable_readonly_testing();
+#endif // TEST_READONLY
+#ifdef TEST_REPLICATIONLAG
+	tables_defs_replicationlag = new std::vector<table_def_t*>;
+	insert_into_tables_defs(tables_defs_replicationlag,
+		(const char*)"REPLICATIONLAG_HOST_STATUS",
+		(const char*)"CREATE TABLE REPLICATIONLAG_HOST_STATUS ("
+		"hostname VARCHAR NOT NULL, port INT NOT NULL, seconds_behind_master INT NOT NULL, PRIMARY KEY (hostname, port)"
+		")"
+	);
 
+	check_and_build_standard_tables(sessdb, tables_defs_replicationlag);
+	GloAdmin->enable_replicationlag_testing();
+#endif // TEST_REPLICATIONLAG
 	child_func[0]=child_mysql;
 	main_shutdown=0;
 	main_poll_nfds=0;
@@ -1633,3 +1733,85 @@ void SQLite3_Server::send_MySQL_ERR(MySQL_Protocol *myprot, char *msg) {
 	myprot->generate_pkt_ERR(true,NULL,NULL,1,1045,(char *)"28000",msg);
 	myds->DSS=STATE_SLEEP;
 }
+
+#ifdef TEST_READONLY
+void SQLite3_Server::load_readonly_table(MySQL_Session *sess) {
+	// this function needs to be called with lock on mutex readonly_mutex already acquired
+	GloAdmin->mysql_servers_wrlock();
+	readonly_map.clear();
+	char *error=NULL;
+	int cols=0;
+	int affected_rows=0;
+    SQLite3_result *resultset=NULL;
+	sessdb->execute_statement((char *)"SELECT * FROM READONLY_STATUS", &error , &cols , &affected_rows , &resultset);
+	if (resultset) {
+		for (std::vector<SQLite3_row *>::iterator it = resultset->rows.begin() ; it != resultset->rows.end(); ++it) {
+			SQLite3_row *r=*it;
+			std::string s = std::string(r->fields[0])+":"+std::string(r->fields[1]);
+			int ro = atoi(r->fields[2]);
+			bool b = ( ro ? true : false );
+			readonly_map[s]=b;
+		}
+	}
+	delete resultset;
+	if (readonly_map.size()==0) {
+		GloAdmin->admindb->execute_statement((char *)"SELECT DISTINCT hostname, port FROM mysql_servers WHERE hostgroup_id BETWEEN 4202 AND 4700", &error , &cols , &affected_rows , &resultset);
+		for (std::vector<SQLite3_row *>::iterator it = resultset->rows.begin() ; it != resultset->rows.end(); ++it) {
+			SQLite3_row *r=*it;
+			std::string s = "INSERT INTO READONLY_STATUS VALUES ('" + std::string(r->fields[0]) + "'," + std::string(r->fields[1]) + ",1)";
+			sessdb->execute(s.c_str());
+		}
+		delete resultset;
+	}
+	GloAdmin->mysql_servers_wrunlock();
+}
+
+int SQLite3_Server::readonly_test_value(char *p) {
+	int rc = 1; // default read_only
+	std::string s = std::string(p);
+	std::unordered_map<std::string, bool>::iterator it = readonly_map.find(s);
+	if (it != readonly_map.end()) {
+		rc = it->second;
+	}
+	return rc;
+}
+#endif // TEST_READONLY
+
+#ifdef TEST_REPLICATIONLAG
+void SQLite3_Server::load_replicationlag_table(MySQL_Session* sess) {
+	GloAdmin->mysql_servers_wrlock();
+	replicationlag_map.clear();
+	char* error = NULL;
+	int cols = 0;
+	int affected_rows = 0;
+	SQLite3_result* resultset = NULL;
+	sessdb->execute_statement((char*)"SELECT * FROM REPLICATIONLAG_HOST_STATUS", &error, &cols, &affected_rows, &resultset);
+	if (resultset) {
+		for (std::vector<SQLite3_row*>::iterator it = resultset->rows.begin(); it != resultset->rows.end(); ++it) {
+			SQLite3_row* r = *it;
+			const std::string& s = std::string(r->fields[0]) + ":" + std::string(r->fields[1]);
+			replicationlag_map[s] = atoi(r->fields[2]);
+		}
+	}
+	delete resultset;
+	if (replicationlag_map.size() == 0) {
+		GloAdmin->admindb->execute_statement((char*)"SELECT DISTINCT hostname, port FROM mysql_servers WHERE hostgroup_id BETWEEN 5202 AND 5700", &error, &cols, &affected_rows, &resultset);
+		for (std::vector<SQLite3_row*>::iterator it = resultset->rows.begin(); it != resultset->rows.end(); ++it) {
+			SQLite3_row* r = *it;
+			const std::string& s = "INSERT INTO REPLICATIONLAG_HOST_STATUS VALUES ('" + std::string(r->fields[0]) + "'," + std::string(r->fields[1]) + ",0)";
+			sessdb->execute(s.c_str());
+		}
+		delete resultset;
+	}
+	GloAdmin->mysql_servers_wrunlock();
+}
+
+int SQLite3_Server::replicationlag_test_value(const char* p) {
+	int rc = 0; // default
+	std::unordered_map<std::string, int>::iterator it = replicationlag_map.find(std::string(p));
+	if (it != replicationlag_map.end()) {
+		rc = it->second;
+	}
+	return rc;
+}
+#endif // TEST_REPLICATIONLAG
