@@ -146,6 +146,8 @@ get_sources(){
     sed -i 's:6.7:6:' src/Makefile
     sed -i '94s|exit 0||' etc/init.d/proxysql
     sed -i "s:GITVERSION:\"${GIT_VERSION}-${RPM_RELEASE}\":g" include/proxysql.h
+    sed -i 's/2.6.0/2.5.5/' Makefile
+    grep CURVER Makefile
     cd ..
     echo "REVISION=${REVISION}" >> ${WORKDIR}/proxysql.properties
     cd ${PRODUCT_FULL}
