@@ -66,70 +66,6 @@ using query_test_info =
 
 // "SET mysql-enable_load_data_local_infile='true'",
 
-
-/**
- * @brief Extract the current value for a given 'variable_name' from
- *   ProxySQL current configuration, either MEMORY or RUNTIME.
- * @param proxysql_admin An already opened connection to ProxySQL Admin.
- * @param variable_name The name of the variable to be retrieved from ProxySQL
- *   config.
- * @param variable_value Reference to string acting as output parameter which
- *   will content the value of the specified variable.
- * @return EXIT_SUCCESS, or one of the following error codes:
- *   - EINVAL if supplied 'proxysql_admin' is NULL.
- *   - '-1' in case of ProxySQL returns an 'NULL' row for the query selecting
- *     the variable 'sqliteserver-read_only'.
- *   - EXIT_FAILURE in case other operation failed.
- */
-int get_variable_value(
-	MYSQL* proxysql_admin, const std::string& variable_name,
-	std::string& variable_value, bool runtime=false
-) {
-	if (proxysql_admin == NULL) {
-		return EINVAL;
-	}
-
-	int res = EXIT_FAILURE;
-
-	const std::string t_select_var_query {
-		"SELECT * FROM %sglobal_variables WHERE Variable_name='%s'"
-	};
-	std::string select_var_query {};
-
-	if (runtime) {
-		string_format(t_select_var_query, select_var_query, "runtime_", variable_name.c_str());
-	} else {
-		string_format(t_select_var_query, select_var_query, "", variable_name.c_str());
-	}
-
-	MYSQL_QUERY(proxysql_admin, select_var_query.c_str());
-
-	MYSQL_RES* admin_res = mysql_store_result(proxysql_admin);
-	if (!admin_res) {
-		diag("'mysql_store_result' at line %d failed: %s", __LINE__, mysql_error(proxysql_admin));
-		goto cleanup;
-	}
-
-	{
-		MYSQL_ROW row = mysql_fetch_row(admin_res);
-		if (!row || row[0] == nullptr || row[1] == nullptr) {
-			diag("'mysql_fetch_row' at line %d returned 'NULL'", __LINE__);
-			res = -1;
-			goto cleanup;
-		}
-
-		// Extract the result
-		std::string _variable_value { row[1] };
-		variable_value = _variable_value;
-
-		res = EXIT_SUCCESS;
-	}
-
-cleanup:
-
-	return res;
-}
-
 /**
  * @brief Enable the query based using the information supplied in the
  *   'query_info' parameter, and verifies that the value of the query has properly
