@@ -33,6 +33,36 @@ TEST(Socketcase, connecterror) {
     }
 }
 
+TEST(Socketcase, timeoutrecv) {
+    using Seconds = std::chrono::seconds;
+
+    int port = 19979;
+    NetworkAddress addr("localhost", std::to_string(port));
+    LocalTcpServer server(port);
+    server.start();
+
+    std::this_thread::sleep_for(std::chrono::seconds(1));
+    try {
+        Socket socket(addr, SocketTimeoutParams { Seconds(5), Seconds(5) });
+
+        std::unique_ptr<InputStream> ptr_input_stream = socket.makeInputStream();
+        char buf[1024];
+        ptr_input_stream->Read(buf, sizeof(buf));
+
+    }
+    catch (const std::system_error& e) {
+#if defined(_unix_)
+        auto expected = EAGAIN;
+#else
+        auto expected = WSAETIMEDOUT;
+#endif
+        ASSERT_EQ(expected, e.code().value());
+    }
+
+    std::this_thread::sleep_for(std::chrono::seconds(1));
+    server.stop();
+}
+
 // Test to verify that reading from empty socket doesn't hangs.
 //TEST(Socketcase, ReadFromEmptySocket) {
 //    const int port = 12345;
